@@ -10,12 +10,12 @@ use XML::Generator::PerlData;
 
 use Moo;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 has 'ua', is => 'ro', default => sub {
     Furl->new(
         agent         => "Net-Moip/$VERSION",
-        timeout       => 5,
+        timeout       => 15,
         max_redirects => 3,
         # <perigrin> "SSL Wants a read first" I think is suggesting you
         # haven't read OpenSSL a bedtime story in too long and perhaps
@@ -23,7 +23,11 @@ has 'ua', is => 'ro', default => sub {
         # see also: https://metacpan.org/pod/IO::Socket::SSL#SNI-Support
         # https://metacpan.org/pod/Furl#FAQ
         # https://rt.cpan.org/Public/Bug/Display.html?id=86684
-        ssl_opts => { SSL_verify_mode => SSL_VERIFY_PEER() }
+        ssl_opts => {
+            SSL_verify_mode => SSL_VERIFY_PEER(),
+            # forcing version yields better error message:
+            SSL_version     => 'TLSv1_2',
+        },
     );
 };
 
@@ -178,7 +182,7 @@ it to your language, please send us some pull requests! :)
 =head1 DESCRIÇÃO
 
 Este módulo funciona como interface entre sua aplicação e a API do Moip.
-Por enquanto apenas a versão 1 da API é suportada, e apenas pagamentos
+Por enquanto B<apenas a versão 1 da API é suportada>, e apenas pagamentos
 únicos.
 
 Toda a API de pagamentos únicos é manipulada através de XMLs sem schema,
@@ -192,12 +196,6 @@ direta, exceto pelas tags C<Valor>, C<Acrescimo> e C<Deducao>, que
 por questões práticas podem opcionalmente ficar no nível mais alto
 da estrutura, como mostrado no exemplo da Sinopse.
 
-O Moip espera que seus dados estejam em I<iso-8859-1>. Este módulo
-fará a coisa certa se seus dados estiverem no formato interno do Perl.
-Se por acaso seus dados já estiverem codificados em I<utf-8> ou
-qualquer outro formato, defina o atributo "L</"decode_as">" para o
-formato desejado.
-
 Outra mudança é que as tags são escritas em I<snake_case> como é
 padrão em Perl, em vez de I<CamelCase> como estão no XML do Moip. Em
 outras palavras, a estrutura:
@@ -214,6 +212,14 @@ deve ser passada na forma:
         estado => 'SP',
     }
 
+=head2 Atenção com o encoding!
+
+O Moip espera que seus dados estejam em I<iso-8859-1>. Este módulo
+fará a coisa certa se seus dados estiverem no formato interno do Perl.
+Se por acaso seus dados já estiverem codificados em I<utf-8> ou
+qualquer outro formato, defina o atributo "L</"decode_as">" para o
+formato desejado.
+
 =head1 EXEMPLOS
 
 =head2 Pagamentos únicos via checkout transparente
@@ -256,6 +262,45 @@ Por padrão, as strings da sua estrutura de dados não são decodificadas.
 Utilize esse atributo para decodificá-las no formato desejado antes de
 recodificá-las em 'iso-8859-1' e enviá-las ao Moip.
 
+=head1 Compatibilidade e SSL/TLS
+
+Como mencionado na descrição, o Net::Moip é compatível apenas com a
+v1 da API do Moip.
+
+Este módulo utiliza os novos endpoints do Moip (api.moip.com.br)
+desde a versão 0.04 do Net::Moip. Se você usa esse módulo, certifique-se
+de que está atualizado. O endpoint antigo da API (www.moip.com.br)
+foi DESATIVADO pelo Moip em 30/9/2015.
+
+Por questões de segurança, o endpoint do Moip exige conexão com
+TLS 1.1 ou 1.2, usando um certificado digital assinado com SHA-256.
+Os protocolos SSLv3 e TLS 1.0 foram completamente desativados.
+
+Para garantir compatibilidade com a API do Moip, este módulo
+por padrão carrega um user agent forçando o uso de TLS 1.2, o que
+gera uma exceção fatal caso seu sistema não aceite o protocolo.
+
+Portanto, se a sua aplicação está retornando exceções com mensagens como:
+
+    SSL connect attempt failed because of handshake problems
+
+ou
+
+    Cannot create SSL connection: SSL Version TLSv1_2 not supported
+
+Você provavelmente precisa atualizar sua versão do OpenSSL para uma que
+entenda TLS 1.2. Uma forma rápida de descobrir é digitar na linha de comando:
+
+    openssl ciphers -sv 'TLSv1.2'
+
+O resultado desse comando deve ser uma lista de cifras separadas por ":".
+Se em vez disso o comando retornar erro ou nenhum resultado, você precisa
+atualizar seu OpenSSL e, em seguida, reinstalar os módulos L<Net::SSLeay>
+e L<IO::Socket::SSL> (nessa ordem). Sugerimos também instalar/atualizar
+o módulo L<Mozilla::CA>, que contém uma cópia dos certificados das CAs
+da Mozilla e é usado pelo IO::Socket::SSL.
+
+Mais detalhes no L<< blog oficial do Moip|https://moip.zendesk.com/hc/pt-br/articles/206767477-Certificado-Digital-com-tecnologia-SHA-256-Guia-de-Upgrade-do-Sistema >>.
 
 =head1 VEJA TAMBÉM
 
